@@ -29,6 +29,7 @@
 #include <telepathy-glib/channel.h>
 #include <telepathy-glib/channel-request.h>
 #include <telepathy-glib/client-channel-factory.h>
+#include <telepathy-glib/defs.h>
 #include <telepathy-glib/handle-channels-context.h>
 
 G_BEGIN_DECLS
@@ -73,7 +74,7 @@ gint64 tp_account_channel_request_get_user_action_time (
 
 void tp_account_channel_request_set_channel_factory (
     TpAccountChannelRequest *self,
-    TpClientChannelFactory *factory);
+    TpClientChannelFactory *factory) _TP_GNUC_DEPRECATED;
 
 
 TpChannelRequest * tp_account_channel_request_get_channel_request (
@@ -82,6 +83,10 @@ TpChannelRequest * tp_account_channel_request_get_channel_request (
 void tp_account_channel_request_set_hints (TpAccountChannelRequest *self,
     GHashTable *hints);
 
+void tp_account_channel_request_set_delegate_to_preferred_handler (
+    TpAccountChannelRequest *self,
+    gboolean delegate);
+
 /* Request and handle API */
 
 void tp_account_channel_request_create_and_handle_channel_async (
@@ -108,6 +113,17 @@ TpChannel * tp_account_channel_request_ensure_and_handle_channel_finish (
     TpHandleChannelsContext **context,
     GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
+typedef void (*TpAccountChannelRequestDelegatedChannelCb) (
+    TpAccountChannelRequest *request,
+    TpChannel *channel,
+    gpointer user_data);
+
+void tp_account_channel_request_set_delegated_channel_callback (
+    TpAccountChannelRequest *self,
+    TpAccountChannelRequestDelegatedChannelCb callback,
+    gpointer user_data,
+    GDestroyNotify destroy);
+
 /* Request and forget API */
 
 void tp_account_channel_request_create_channel_async (
