@@ -34,8 +34,7 @@ int
 main (int argc,
     char **argv)
 {
-  tp_tests_abort_after (10);
-  g_test_init (&argc, &argv, NULL);
+  tp_tests_init (&argc, &argv);
 
   g_test_add_func ("/test-get-interface-after-invalidate",
       test_get_interface_after_invalidate);
